@@ -16,8 +16,9 @@
 #'
 #' @return An example \var{bdm} instance named \var{exMap}.
 #'
-#' @details A \var{bdm} instance is a list with elements: \var{$dSet} a name identifying the dataset (\code{bdm.fName()} use this name to generate a default file name to be used by \code{bdm.save()} and \code{bdm.scp()}; \var{$data} a matrix with raw data; \var{$lbls} a vector of datapoint labels in case they are known; \var{$N} the dataset size; \var{$is.distance} a logical value that is set to TRUE when the raw data is a distance matrix. As the protocol steps are performed, more elements are appended to the list, basically: \var{$ptsne} holds the parameters and output of the t-SNE; \var{$pakde} holds the parameters and output of the paKDE; \var{$wtt} holds the output of the WTT.
-#' This example corresponds to the mapping of a small synthetic dataset with \code{n = 5000} observations drawn from a 4-variate Gaussian Mixture Model (GMM) with 16 Gaussian components.
+#' @details A \var{bdm} instance is a list with elements: \var{$dSet} a name identifying the dataset (\code{bdm.fName()} use this name to generate a default file name); \var{$data} a matrix with raw data; \var{$lbls} a vector of datapoint labels (in case they are known); \var{$N} the dataset size; \var{$is.distance} a logical value that is set to TRUE when the raw data is a distance matrix. Downstream steps of the mapping protocol will add more elements to the list.
+#'
+#' This example is based on a small synthetic dataset with \code{n = 5000} observations drawn from a 4-variate Gaussian Mixture Model (GMM) with 16 Gaussian components.
 #'
 #' @examples
 #'
@@ -27,13 +28,13 @@
 
 bdm.example <- function()
 {
-	load(paste(exbdm, 'exMap.RData', sep=''), envir=parent.frame(), verbose=T)
+	load(paste(paste(system.file('extdata', package = 'bigMap'), '/', sep = ''), 'exMap.RData', sep=''), envir=parent.frame(), verbose=T)
 }
 
 
 #' Create \var{bdm} instance
 #'
-#' Creates a \var{bdm} instance from
+#' Creates a \var{bdm} instance.
 #'
 #' @param dSet.name The name given to the input dataset. This name will be used to automatically generate a name to save the output as an \var{.Rdata} file.
 #'
@@ -41,11 +42,11 @@ bdm.example <- function()
 #'
 #' @param labels If available, labels can be included as a separate vector of length equal to \code{nrow(dSet.data)}. Label values are factorized as \code{as.numeric(as.factor(labels))}.
 #'
-#' @param is.distance A logical value (FALSE by default). TRUE indicates that raw data is indeed a distance matrix.
+#' @param is.distance A logical value (FALSE by default). TRUE indicates that the raw data is indeed a distance matrix.
 #'
 #' @param check.duplicates If set to TRUE (default value) the dataset is checked for duplicated rows. Checking for duplicates in big datasets can take some time. If the dataset is known to have no duplicates disabling this option will save time.
 #'
-#' @return A \var{bdm} instance. A \var{bdm} instance is initially a list with a few elements (data and dataset information) to which new elements are added at each step of the mapping protocol.
+#' @return A \var{bdm} instance. A \var{bdm} instance is initially a list with a few elements to which new elements are added at each step of the mapping protocol.
 #'
 #' @examples
 #'
@@ -79,9 +80,9 @@ bdm.init <- function(dSet.name, dSet.data, labels = NULL, is.distance = F, check
 #'
 #' @param bdm A \var{bdm} instance as generated by \code{bdm.init()}.
 #'
-#' @details The file name is generated based on \code{bdm$dSet} and main ptSNE parameters (threads, layers, rounds, boost and perplexity). In the case that \code{bdm.wtt()} has been performed on any of the layers, the number of clusters in the first not null layer of bdm$wtt is also included.
+#' @details The file name is generated based on \code{bdm$dSet} and main ptSNE parameters (threads, layers, rounds, boost and perplexity). In case that \code{bdm.wtt()} has been performed on any of the layers, the number of clusters in the first not null layer of bdm$wtt is also included.
 #'
-#' @return A \var{*.ext} file name based on \var{bdm$dSet} and main \var{bdm} parameters.
+#' @return A \var{*.RData} file name based on \var{bdm$dSet} and main \var{bdm} parameters.
 #'
 #' @examples
 #'
@@ -119,7 +120,7 @@ bdm.fName <- function(bdm)
 
 #' Save \var{bdm} instance
 #'
-#' Saves a \var{bdm} instance with default path/file names, as given by \code{bdm.mybdm()/bdm.fName(bdm)}. Default file name is generated based on \code{bdm$dSet} and ptSNE main parameters (threads, layers, rounds, perplexity).  The purpose of functions \code{bdm.save()} and \code{bdm.scp()} used with \code{bdm.fName()} is to ease the task of working/organizing multiple runs on the same dataset.
+#' Saves a \var{bdm} instance with default path/file names, as given by \code{bdm.mybdm()/bdm.fName(bdm)}. Default file name is generated based on \code{bdm$dSet} and ptSNE main parameters (threads, layers, boost, rounds, perplexity).  The purpose of functions \code{bdm.save()} and \code{bdm.scp()} used with \code{bdm.fName()} is to ease the task of working/organizing multiple runs on the same dataset.
 #'
 #' @param ... A \var{bdm} instance as generated by \code{bdm.init()}.
 #'
@@ -191,11 +192,13 @@ bdm.scp <- function( ... , dest = NULL){
 
 #' Parallelized t-SNE
 #'
+#' Starts the ptSNE algorithm (first step of the mapping protocol).
+#'
 #' @param bdm A \var{bdm} instance as generated by \code{bdm.init()}.
 #'
 #' @param threads The number of parallel threads (in principle only limited by hardware resources, \code{i.e.} number of cores and available memory)
 #'
-#' @param type The type of cluster: 'SOCK' (default) for intra-node parallelization, 'MPI' for inter-node parallelization (\code{message passing interface} parallel environment).
+#' @param type The type of cluster: 'SOCK' (default) for intra-node parallelization, 'MPI' (\code{message passing interface}) for inter-node parallelization.
 #'
 #' @param layers The number of layers (\code{minimum} 2, \code{maximum} the number of threads).
 #'
@@ -203,7 +206,7 @@ bdm.scp <- function( ... , dest = NULL){
 #'
 #' @param boost A running time accelerator factor. By default (\code{boost == 1}). See details.
 #'
-#' @param whiten Preprocessing of raw data. If \code{whiten = 4} (default value) raw data is preprocessed by computing the principal components (PCA) and whitening the rotated data. If \code{whiten = 3} only PCA is performed without whitening. If \code{whiten = 2} raw data is only centered and scaled. If \code{whiten = 1} raw data is only centered. If \code{whiten = 0} no preprocessing is performed at all.
+#' @param whiten Preprocessing of raw data. If \code{whiten = 4} (default value) raw data is preprocessed by computing the principal components (PCA) and whitening the rotated data. If \code{whiten = 3} only PCA is performed with NO whitening. If \code{whiten = 2} raw data is only centered and scaled. If \code{whiten = 1} raw data is only centered. If \code{whiten = 0} no preprocessing is performed at all.
 #'
 #' @param input.dim If \var{whiten} is TRUE, input.dim sets the number of principal components to be used as input dimensions. By default \code{input.dim = min(ncol(bdm$data), 30)}. If \var{whiten} is FALSE all data columns will be used as input dimensions (\code{input.dim = ncol(bdm$data)}).
 #'
@@ -221,8 +224,9 @@ bdm.scp <- function( ... , dest = NULL){
 #'
 #' @return A copy of the input \var{bdm} instance with new element \var{bdm$ptsne} (t-SNE output).
 #'
-#' @details By default the algorithm is structured in \eqn{\sqrt{n}} epochs of \eqn{\sqrt{z}} iterations each, where \emph{n} is the dataset size and \emph{z} is the thread-size (\eqn{z=\,n\,layers/threads}). The running time of the algorithm is then determined by \eqn{epochs\,iters\,t_{i} + epochs\,t_{e}} where \eqn{t_{i}} is the running time of a single iteration and \eqn{t_{e}} is the inter-epoch running time.
-#'The \var{boost} factor is meant to reduce the running time. With \eqn{boost > 1} the algorithm is structured in \eqn{n/boost} epochs with \eqn{z*boost} iterations each. This structure performs the same total number of iterations with a smaller number of epochs, thus decreasing the the total running time to \eqn{epochs\,iters\,t_{i} + 1/boost\,epochs\,t_{e}}. When the number of threads is high, the inter-epoch time can be high, in particular when using 'MPI' parallelization, thus, reducing the number of epochs can result in a significant reduction of the total running time. The counterpart is that increasing the number of iterations per epoch might result in a lack of convergence, thus the \var{boost} factor must be used with caution. To the most of our knowledge using values up to \code{boost = 2.5} is generally safe.
+#' @details By default the algorithm is structured in \eqn{\sqrt{n}} epochs of \eqn{\sqrt{z}} iterations each, where \var{n} is the dataset size and \var{z} is the thread-size (\eqn{z=n*layers/threads}). The running time of the algorithm is then determined by \eqn{epochs*iters*t_i+ epochs*t_e} where \var{t_{i}} is the running time of a single iteration and \var{t_{e}} is the inter-epoch running time.
+#'
+#'The \var{boost} factor is meant to reduce the running time. With \eqn{boost > 1} the algorithm is structured in \eqn{n/boost} epochs with \eqn{z*boost} iterations each. This structure performs the same total number of iterations but arranged into a lower number of epochs, thus decreasing the total running time to \eqn{epochs*iters*t_i + 1/boost*epochs*t_e}. When the number of threads is high, the inter-epoch time can be high, in particular when using 'MPI' parallelization, thus, reducing the number of epochs can result in a significant reduction of the total running time. The counterpart is that increasing the number of iterations per epoch might result in a lack of convergence, thus the \var{boost} factor must be used with caution. To the most of our knowledge using values up to \eqn{boost=2.5} is generally safe.
 
 #' @examples
 #'
@@ -271,27 +275,31 @@ bdm.ptsne <- function(bdm, threads = 3, type = 'SOCK', layers = 2, rounds = 1, b
 
 #' Perplexity-adaptive kernel density estimation
 #'
+#' Starts the paKDE algorithm (second step of the mapping protocol).
+#'
 #' @param bdm A \var{bdm} instance as generated by \code{bdm.init()}.
 #'
 #' @param layer The number of the t-SNE layer (1 by default).
 #'
 #' @param threads The number of parallel threads (in principle only limited by hardware resources, \code{i.e.} number of cores and available memory)
 #'
-#' @param type The type of cluster: 'SOCK' (default) for intra-node parallelization, 'MPI' for inter-node parallelization (\code{message passing interface} parallel environment).
+#' @param type The type of cluster: 'SOCK' (default) for intra-node parallelization, 'MPI' (\code{message passing interface}) for inter-node parallelization.
 #'
-#' @param ppx The value of perplexity to compute similarities (100 by default).
+#' @param ppx The value of perplexity to compute similarities in the low-dimensional embedding (100 by default).
 #'
 #' @param itr The number of iterations for computing input similarities (100 by default).
 #'
 #' @param tol The tolerance lower bound for computing input similarities (1e-05 by default).
 #'
-#' @param g The resolution of the density space grid (\code{g*g} cells, 200 by default).
+#' @param g The resolution of the density space grid (\eqn{g*g} cells, 200 by default).
 #'
-#' @param g.exp A numeric factor to avoid border effects. The grid limits will be expanded so as to enclose the density of the kernel of the most extreme mapped points up to \code{g.exp} times \eqn{\sigma}. By default, (\code{g.exp = 3}) the grid limits are expanded so as to enclose the 0.9986 of the probability mass of the most extreme kernels.
+#' @param g.exp A numeric factor to avoid border effects. The grid limits will be expanded so as to enclose the density of the kernel of the most extreme embedded datapoints up to \code{g.exp} times \eqn{\sigma}. By default, (\code{g.exp = 3}) the grid limits are expanded so as to enclose the 0.9986 of the probability mass of the most extreme kernels.
 #'
 #' @details When computing the \var{paKDE} the embedding area is discretized as a grid of size \code{g*g} cells. In order to avoid border effects, the limits of the grid are expanded by default so as to enclose at least the 0.9986 of the cumulative distribution function (\eqn{3 \sigma}) of the kernels of the most extreme mapped points in each direction.
-#' The existence of outliers in the mapping can lead to undesired expansion of the grid limits. We can overcome this using lower values of \var{g.exp}. By setting \code{g.exp = 0} the grid limits will be equal to the range of the embedding.
-#' Values of \var{g.exp = c(0, 1, 2, 3, 4, 5, 6)} enclose cdf values of \var{0, 0.8413, 0.9772, 0.9986, 0.99996, 0.99999, 1.0} respectively.
+#'
+#' The presence of outliers in the embedding can lead to undesired expansion of the grid limits. We can overcome this using lower values of \var{g.exp}. By setting \code{g.exp = 0} the grid limits will be equal to the range of the embedding.
+#'
+#' The values \var{g.exp = c(1, 2, 3, 4, 5, 6)} enclose cdf values of \var{0.8413, 0.9772, 0.9986, 0.99996, 0.99999, 1.0} respectively.
 #'
 #' @return A copy of the input \var{bdm} instance with new element \var{bdm$pakde} (paKDE output). \code{bdm$pakde[[layer]]$layer = 'NC'} stands for not computed layers.
 #'
@@ -330,6 +338,8 @@ bdm.pakde <- function(bdm, layer = 1, threads = 2, type = 'SOCK', ppx = 100, itr
 
 #' Watertrack transform (WTT)
 #'
+#' Starts the WTT algorithm (third setp of the mapping protocol).
+#'
 #' @param bdm A \var{bdm} instance as generated by \code{bdm.init()}.
 #'
 #' @param layer The number of the t-SNE layer (1 by default).
@@ -371,7 +381,7 @@ bdm.wtt <- function(bdm, layer = 1)
 #'
 #' @param layer The number of the t-SNE layer (1 by default).
 #'
-#' @param merged A logical value. If TRUE (default value) and the \var{bdm} has been merged, the returned data-point labelling correspond to merged clusters. If \var{merged} is set to FALSE or the \var{bdm} has not been merged the data-point labels that are returned correspond to the top-level clustering.
+#' @param merged A logical value. If TRUE (default value) and the \var{bdm} has been merged, the data-point labelling indicate the number of the merged clusters. If \var{merged} is set to FALSE or the \var{bdm} has not been merged the data-point labels correspond to the top-level clustering.
 #'
 #' @return A vector of data-point clustering labels.
 #'
